MiPay class

Constructors

MiPay()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCallback(SDKCallback callback) → void
调用支付之前添加回调
initSDK({required String appId, required String appKey, bool isDebug = false}) Future<void>
初始化sdk
isLogin() Future<bool>
获取登录状态
login() Future<void>
开始登录
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pay({required int feeValue, String? orderId}) Future<void>
支付(消耗型商品)
payProduct({required String productCode, required int amount, String? orderId}) Future<void>
支付(非消耗类商品)
subscribe({required int feeValue, String? orderId}) Future<void>
订阅(消耗型商品)
subscribeProduct({required String productCode, required int amount, String? orderId}) Future<void>
订阅(非消耗型商品)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited